qparser module
==============

.. automodule:: whoosh.qparser

Parser classes
--------------

.. autoclass:: QueryParser
    :inherited-members:
    :members:
    
.. autoclass:: MultifieldParser

.. autoclass:: SimpleParser

.. autoclass:: SimpleNgramParser

